XlsXcessive - Changes
=====================

0.2.0 - 2015/11/23
------------------

* Improved compatibility with Python 3
* Add support for the style parameter on a column.
* Add support for 'best fit' parameter on a column.

0.1.6 - 2010/11/15
------------------

* Performance improvements (memory and speed)

